import 'package:mapbox_flutter_search_sdk/api/models/forward_geocoding.model.dart';
import 'package:mapbox_flutter_search_sdk/api/models/reverse_geocoding.model.dart';
import 'package:mapbox_flutter_search_sdk/api/providers/api.provider.dart';
import 'package:mapbox_flutter_search_sdk/api/repositories/iapi.repository.dart';

class ApiRepository implements IApiRepository {
  static final ApiRepository instance = ApiRepository._();
  final ApiProvider _provider = ApiProvider();

  ApiRepository._();

  @override
  Future<ReverseGeocodingModel> performReverseGeocoding(
    double latitude,
    double longitude,
    String mapboxApiKey,
  ) async {
    final result = await _provider.makeGetRequest(
      '/geocoding/v5/mapbox.places/$latitude,$longitude.json',
      queryParams: {
        'types': 'region',
        'access_token': mapboxApiKey,
      },
    );
    return result != null
        ? ReverseGeocodingModel.fromJson(result)
        : ReverseGeocodingModel();
  }

  @override
  Future<ForwardGeocodingModel> performForwardGeocoding(
    String query,
    String mapboxApiKey,
  ) async {
    print('query:' + query);
    final result = await _provider.makeGetRequest(
      '/geocoding/v5/mapbox.places/$query.json',
      queryParams: {
        'country': 'SI',
        'access_token': mapboxApiKey,
      },
    );
    print(result);
    return result != null
        ? ForwardGeocodingModel.fromJson(result)
        : ForwardGeocodingModel();
  }
}
